import asyncio
from pyppeteer import launch


async def start_browser():
    browser = await launch(
        headless=False,  # 设置为 False 可以看到浏览器界面
        args=["--no-sandbox", "--disable-gpu"]
    )
    return browser


from fastapi import FastAPI
from starlette.responses import HTMLResponse

app = FastAPI()


@app.get("/test1", response_class=HTMLResponse)
async def index():
    browser = await start_browser()
    page = await browser.newPage()
    await page.goto("https://www.example.com")
    html = await page.content()
    await browser.close()
    return html


if __name__ == '__main__':
    # 该方法作用是阻止子进程运行其后面的代码 ----
    import uvicorn
    print("url             http://127.0.0.1:9999/docs          ")
    print("url             http://127.0.0.1:9999/static/logo.png            ")
    print("url             http://127.0.0.1:9999/main?num=1              ")
    print("url             http://127.0.0.1:9999/xiaohongshu?num=1              ")

    # ------------------------------------
    # uvicorn.run("main:app", host='0.0.0.0', port=9999, reload=True, workers=1)
    # uvicorn.run(app, host='0.0.0.0', port=9999, reload=True, workers=1)
    uvicorn.run(app, host='0.0.0.0',  port=9999, reload=True, workers=1)
    # thread.join()
    # uvicorn.run("p1:app", host='0.0.0.0', port=9999, reload=False)




import shutil, os, pathlib


def delete(file_path):
    my_error = ""
    # # 判断绝对路径
    # if not os.path.isabs(file_path):
    #     my_error = my_error + f"1请检查路径是不是绝对路径|      {file_path}"

    # 判断存在文件吗
    if not os.path.exists(file_path):
        my_error = my_error + f"2请检查路径是否存在      |       {file_path}"

    # 执行_删除文件
    if pathlib.Path(file_path).is_file():
        os.remove(file_path)

    # 执行_删除文件夹
    if pathlib.Path(file_path).is_dir():
        shutil.rmtree(file_path, ignore_errors=True)

    if not my_error == "":
        print("fs.delete            my_error:", my_error)


if __name__ == '__main__':
    # run_file_delete("aaa.txt")
    delete(r"E:\AAA\xxx\ast_chrome\a08_驱动测试_cookie_打包_发布\astmain_py222\astmain\fs\aaa.txt")



from .delete import delete
from .cwd import cwd
from .read import read
from .write import write
from .write_add import write_add
from .fs_write_add import fs_write_add
from .log_info import log_info
from .fs_find_file import fs_find_file




import builtins

old_print = print

is_debugger = True


def log(*args, **kwargs):
    if is_debugger: old_print(*args, **kwargs)


# 替换内置的 print 函数
#
#
# builtins.print = log
#
# # 使用自定义的 print 函数
# print("Hello, world!")
# print("This is a test.", "Additional message.", sep="-")



# 要使用win32api来控制Windows任务栏的透明度，你需要调用Windows的API函数。以下是一个简单的Python脚本，用于设置任务栏的透明度：

import win32gui
import win32con
import ctypes


# 定义一个结构体用来表示透明度信息
class TRANSPARENCY_INFO(ctypes.Structure):
    _fields_ = [
        ('cbSize', ctypes.c_ulong),
        ('dwFlags', ctypes.c_ulong),
        ('rgba', ctypes.c_ulong),
        ('hRgnBlur', ctypes.c_void_p)
    ]


# 设置透明度的常量
LWA_ALPHA = 0x2

# 要设置的透明度值，范围从0到255
alpha = 0

# 创建透明度信息
transparency_info = TRANSPARENCY_INFO()
transparency_info.cbSize = ctypes.sizeof(TRANSPARENCY_INFO)
transparency_info.dwFlags = LWA_ALPHA
transparency_info.rgba = (alpha << 24)

# 获取任务栏窗口句柄
taskbar_handle = win32gui.FindWindow(None, "web - Google Chrome")
print("taskbar_handle                 :" ,  taskbar_handle   )

# 设置透明度
win32gui.SetWindowLong(taskbar_handle, win32con.GWL_EXSTYLE, win32gui.GetWindowLong(taskbar_handle, win32con.GWL_EXSTYLE) | win32con.WS_EX_LAYERED)

ctypes.windll.user32.SetLayeredWindowAttributes(taskbar_handle, 0, alpha, win32con.LWA_ALPHA)

print("111                 :" ,  111   )

# ctypes.windll.user32.SetLayeredWindowAttributes(taskbar_handle, 0, alpha / 255.0, win32con.LWA_ALPHA)
#
# 请注意，这段代码需要在Windows环境下运行，并且需要安装pywin32库。代码中的透明度值alpha是一个0到255之间的整数，代表任务栏的透明度，其中255表示完全不透明，而0表示完全透明。
#
# 运行这段代码后，你会发现任务栏的透明度被设置为你指定的值。请谨慎使用此功能，因为过度的透明可能会影响用户界面的可用性。


import win32gui
import win32con


def win_find_name(name) -> dict:
    """ 通过标题名称获取程序窗口数据 nane
        code  :
        print("win                 :", win_find_name("Postman111"))

    """
    windows = []

    def callback(hwnd, param):
        title = win32gui.GetWindowText(hwnd)
        name_class = win32gui.GetClassName(hwnd)
        left, top, right, bottom = win32gui.GetWindowRect(hwnd)
        style = win32gui.GetWindowLong(hwnd, win32con.GWL_STYLE)
        if (name in title):
            obj1 = dict(title=title, name_class=name_class, hwnd=hwnd, left=left, right=right, top=top, bottom=bottom, style=style)
            windows.append(obj1)
        return True

    win32gui.EnumWindows(callback, None)

    if len(windows) >= 1:
        return windows[0]
    else:
        return None


if __name__ == '__main__':
    print("win                 :", win_find_name("Postman"))



# coding=utf-8
import re


# 没有完善
def num(xxx):
    """ EXPLAIN : 数据转数字_没有完善
        EXAMPLE :  print("result                 :", __.to.num("-111.222"))
    """
    try:
        res = "".join(re.findall(r'[0-9.-]', xxx))
        return float(res)
    except Exception as error:
        return 0


if __name__ == '__main__':
    print("result                 :", num("-111.222"))



import win32gui
import win32con
import win32api
import win32api
import win32con
import os
import astmain as __

obj1 = __.wind_find_name("Goog")
print("111                 :", obj1)

# win32gui.ShowWindow(obj1["hwnd"], 0)


# 隐藏主窗口
win32gui.SetWindowPos(obj1["hwnd"], win32con.HWND_HIDDEN, 0, 0, 0, 0, win32con.SWP_NOMOVE | win32con.SWP_NOSIZE)

obj1 = __.wind_find_name("Goog")
print("obj1                 :", obj1)
win32gui.SetWindowLong(obj1["hwnd"], win32con.GWL_STYLE, win32gui.GetWindowLong(obj1["hwnd"], win32con.GWL_STYLE) & ~win32con.WS_VISIBLE)



import win32api
import win32con
import win32gui


def set_taskbar_size(width, height, transparent=False):
    """
    设置任务栏大小并控制其可见性和透明度

    参数:
    width (int): 任务栏宽度
    height (int): 任务栏高度
    transparent (bool): 是否设置任务栏透明
    """
    # 获取当前屏幕分辨率
    screen_width = win32api.GetSystemMetrics(win32con.SM_CXSCREEN)
    screen_height = win32api.GetSystemMetrics(win32con.SM_CYSCREEN)

    # 计算任务栏位置
    taskbar_left = (screen_width - width) // 2
    taskbar_top = screen_height - height

    # 查找任务栏窗口
    def enum_windows_callback(hwnd, param):
        text = win32gui.GetWindowText(hwnd)
        # print("text                 :" ,  text   )
        class_name = win32gui.GetClassName(hwnd)
        if text == "web - Google Chrome":
            print("text                 :" ,  text   )
            param[0] = hwnd
            return False
        return True

    taskbar_handle = None
    win32gui.EnumWindows(enum_windows_callback, [taskbar_handle])

    # 设置任务栏大小
    win32gui.SetWindowPos(
        taskbar_handle,
        win32con.HWND_TOP,
        taskbar_left,
        taskbar_top,
        width,
        height,
        win32con.SWP_SHOWWINDOW
    )

    # 设置任务栏可见性和透明度
    if transparent:
        win32gui.SetWindowLong(taskbar_handle, win32con.GWL_EXSTYLE, win32con.WS_EX_LAYERED)
        win32gui.SetLayeredWindowAttributes(taskbar_handle, 0, 128, win32con.LWA_ALPHA)
    else:
        win32gui.SetWindowLong(taskbar_handle, win32con.GWL_EXSTYLE, 0)
        win32gui.SetLayeredWindowAttributes(taskbar_handle, 0, 255, win32con.LWA_ALPHA)


if __name__ == '__main__':
    # 设置任务栏大小为 800x50 像素
    # 设置任务栏大小为 800x50 像素,并设置为透明
    set_taskbar_size(800, 50, transparent=True)

    # 设置任务栏大小为 800x50 像素,并设置为不透明
    set_taskbar_size(800, 50, transparent=False)
